View source: R/internal_functions.R
| sample_lm_ridge | R Documentation |
Sample the parameters for a linear regression model assuming a
ridge prior for the (non-intercept) coefficients. The number of predictors
p may exceed the number of observations n.
sample_lm_ridge(y, X, params, A = 10^4, XtX = NULL, X_test = NULL)
y |
|
X |
|
params |
the named list of parameters containing
|
A |
the prior scale for |
XtX |
the |
X_test |
matrix of predictors at test points (default is NULL) |
The updated named list params with draws from the full conditional distributions
of sigma and coefficients (along with updated mu and mu_test if applicable).
The parameters in coefficients are:
beta: the p x 1 vector of regression coefficients
sigma_beta: the prior standard deviation for the (non-intercept)
components of beta
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.