Compute the inverse transformation on a vector of real-valued inputs based on the marginal CDF of z and the marginal CDF of y.
Note
The inputs for Fz_eval do not need to be known to compute
the inverse transformation, so they are not required for this function.
The function will return NA if Fz_eval is greater than all
Fy_eval values. When y_max < Inf, this implies that the inverse
is y_max; otherwise, it means that y_grid needs to use
larger values. Both are handled externally.