Learn R Programming

countSTAR (version 1.2.0)

g_inv: Inverse transformation

Description

Compute the inverse transformation on a vector of real-valued inputs based on the marginal CDF of z and the marginal CDF of y.

Usage

g_inv(Fz_eval, Fy_eval, y_grid)

Value

The inverse transformation function evaluated on the same inputs as Fz_eval.

Arguments

Fz_eval

the marginal CDF of z evaluated on some inputs

Fy_eval

the marginal CDF of y evaluated on y_grid

y_grid

a grid of non-negative integers